@@ -20,5 +20,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""The place where everything starts :)
-"""
+"""The place where everything starts :)."""
+from ._version import get_versions
+__version__ = get_versions()['version']
+del get_versions
