@@ -20,22 +20,18 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""The tests package.
-"""
+"""The tests package."""
 
 import unittest
 # import doctest
 from pytroll_collectors.tests import (test_helper_functions,
                                       test_scisys,
                                       test_trigger,
-                                      test_global_mosaic,
-                                      test_image_scaler,
                                       test_segments)
 
 
 def suite():
-    """The global test suite.
-    """
+    """Test suite."""
     mysuite = unittest.TestSuite()
     # Test the documentation strings
     # mysuite.addTests(doctest.DocTestSuite(image))
@@ -43,8 +39,6 @@ def suite():
     mysuite.addTests(test_helper_functions.suite())
     mysuite.addTests(test_scisys.suite())
     mysuite.addTests(test_trigger.suite())
-    mysuite.addTests(test_global_mosaic.suite())
-    mysuite.addTests(test_image_scaler.suite())
     mysuite.addTests(test_segments.suite())
 
     return mysuite
